=======
History
=======

0.1.2 (2019-10-24)
==================

- Fixed a bug where hts files were opened in the wrong mode, with
  inconsistent results.

0.1.1 (2019-07-18)
==================

- Fixed a spurious RuntimeWarning.
- Improved error message if the altitude or location is missing in an
  input file.

0.1.0 (2019-06-21)
==================

- Initial release
